==> subtitlecomposer-0.4.1.tar.bz2: subtitlecomposer-0.4.1/src/main/dialogs/changetextscasedialog.h <==
#ifndef CHANGETEXTSCASEDIALOG_H
#define CHANGETEXTSCASEDIALOG_H

/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#include "targetabletextsactiondialog.h"
#include <subtitle.h>

class QCheckBox;
class QRadioButton;

namespace SubtitleComposer
{
	class ChangeTextsCaseDialog : public TargetableTextsActionDialog
	{
		Q_OBJECT

		public:

			typedef enum { Upper=0, Lower, Title, Sentence } CaseOp;

			ChangeTextsCaseDialog( QWidget* parent=0 );

			CaseOp caseOperation();
			bool lowerFirst();

		private slots:

			void onCaseGroupBoxClicked( int id );

		private:

			QCheckBox* m_lowerFirstCheckBox;

			QRadioButton* m_lowerRadioButton;
			QRadioButton* m_upperRadioButton;
			QRadioButton* m_titleRadioButton;
			QRadioButton* m_sentenceRadioButton;
	};
}

#endif

==> subtitlecomposer-0.4.3.tar.bz2: subtitlecomposer-0.4.3/src/main/dialogs/changetextscasedialog.h <==
#ifndef CHANGETEXTSCASEDIALOG_H
#define CHANGETEXTSCASEDIALOG_H

/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#include "actionwithtargetdialog.h"
#include <subtitle.h>

class QCheckBox;
class QRadioButton;

namespace SubtitleComposer
{
	class ChangeTextsCaseDialog : public ActionWithTargetDialog
	{
		Q_OBJECT

		public:

			typedef enum { Lower=0, Upper, Title, Sentence } CaseOp;

			ChangeTextsCaseDialog( QWidget* parent=0 );

			CaseOp caseOperation() const;
			bool lowerFirst() const;

		private slots:

			void onCaseButtonGroupClicked( int id );

		private:

			QCheckBox* m_lowerFirstCheckBox;

			QRadioButton* m_lowerRadioButton;
			QRadioButton* m_upperRadioButton;
			QRadioButton* m_titleRadioButton;
			QRadioButton* m_sentenceRadioButton;
	};
}

#endif
